@@ -39,7 +39,6 @@ class MysqlPool(BaseConnectionPool):
     def sync_create_pool(self):
         pool = PooledDB(creator=pymysql, host=self.conn_info.host, port=self.conn_info.port, user=self.conn_info.user,
                         passwd=self.conn_info.password, db=self.conn_info.db_name,
-                        mincached=self.conn_info.min_size, maxcached=self.conn_info.max_size,
-                        ping=1, maxconnections=self.conn_info.max_size, maxshared=self.conn_info.min_size,
-                        maxusage=self.conn_info.min_size, charset="utf8mb4", autocommit=True)
+                        mincached=self.conn_info.min_size, blocking=False,
+                        ping=1, maxconnections=self.conn_info.max_size, charset="utf8mb4", autocommit=True)
         return pool
